@@ -44,11 +44,9 @@ test_that("pubkey ssh fingerprint", {
   expect_equal(fp, "2378e98f946fbe07c28308835f932834a374a215ae515f65b77678613e412101")
 })
 
-test_that("signatures", {
-  # ecdsa384 does not support MD5
+test_that("SHA1 signatures", {
+  skip_on_redhat()
   msg <- readBin("../keys/message", raw(), 100)
-
-  # SHA1 signature
   sig <- readBin("../keys/message.sig.ecdsa384.sha1", raw(), 1000)
   expect_true(signature_verify(msg, sig, sha1, pk1))
   expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
@@ -56,8 +54,10 @@ test_that("signatures", {
   sig <- signature_create(msg, sha1, sk1)
   expect_true(signature_verify(msg, sig, sha1, pk1))
   expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
+})
 
-  # SHA256 signature
+test_that("SHA56 signatures", {
+  msg <- readBin("../keys/message", raw(), 100)
   sig <- readBin("../keys/message.sig.ecdsa384.sha256", raw(), 1000)
   expect_true(signature_verify(msg, sig, sha256, pk1))
   expect_equal(names(ecdsa_parse(sig)), c("r", "s"))
@@ -72,6 +72,8 @@ test_that("roundtrip pem format", {
   expect_equal(sk1, read_key(write_pem(sk1, password = NULL)))
   expect_equal(pk1, read_pubkey(write_pem(pk1, tempfile())))
   expect_equal(sk1, read_key(write_pem(sk1, tempfile(), password = NULL)))
+  expect_equal(sk1, read_key(write_openssh_pem(sk1, tempfile())))
+  expect_equal(pk1, read_pubkey(write_openssh_pem(sk1, tempfile())))
 })
 
 test_that("roundtrip der format", {
